diff --git a/js/003-data/slaveWearData.js b/js/003-data/slaveWearData.js
index 3065a6f92244edee870259e64aa2ea999902cf65..9c719087d7281d45f7fffc7c99c11399c2f0c1ee 100644
--- a/js/003-data/slaveWearData.js
+++ b/js/003-data/slaveWearData.js
@@ -1,4 +1,4 @@
-App.Data.misc = {
+App.Data.slaveWear = {
 	/**
 	 * @typedef {object} slaveWear
 	 * @property {string} name
diff --git a/src/events/eventUtils.js b/src/events/eventUtils.js
index 5eaf384ca872d04783dedb6a0bd1c4fbae86f3e0..bde85a986a287afa92d36436682c29e1a7b2101b 100644
--- a/src/events/eventUtils.js
+++ b/src/events/eventUtils.js
@@ -1,5 +1,5 @@
 App.Events.drawEventArt = (function() {
-	const validSingleOutfits = App.Data.misc.niceClothes.map(c => c.value).concat(App.Data.misc.harshClothes.map(c => c.value));
+	const validSingleOutfits = App.Data.slaveWear.niceClothes.map(c => c.value).concat(App.Data.slaveWear.harshClothes.map(c => c.value));
 
 	/** draw event art, with the option to dress the slave in a particular way
 	 * @param {Node} node - DOM node to attach art to
diff --git a/src/facilities/wardrobe/wardrobeShopping.js b/src/facilities/wardrobe/wardrobeShopping.js
index e1aeb31be6eaa9e753ac5db7427a51b10a41b638..3614f419b7581a5d1c514cc747eb8087be7756f9 100644
--- a/src/facilities/wardrobe/wardrobeShopping.js
+++ b/src/facilities/wardrobe/wardrobeShopping.js
@@ -8,8 +8,8 @@ App.UI.WardrobeShopping = function() {
 	let r = [];
 	r.push(`The room containing all the clothes and accessories you have available to dress your slaves in, as well as the supplies and tools your tailor needs to resize them to better fit your slaves. Several mirrors are set up for a slave to try on outfits should they be allowed to dress themselves. The selection includes`);
 	const ownItAll = (
-		App.Data.misc.niceClothes.every((i) => isItemAccessible.entry(i.value, "clothing")) &&
-		App.Data.misc.harshClothes.every((i) => isItemAccessible.entry(i.value, "clothing"))
+		App.Data.slaveWear.niceClothes.every((i) => isItemAccessible.entry(i.value, "clothing")) &&
+		App.Data.slaveWear.harshClothes.every((i) => isItemAccessible.entry(i.value, "clothing"))
 	);
 	if (ownItAll) {
 		r.push(`outfits from all manner of cultures and societies; not a single style eludes you.`);
diff --git a/src/interaction/slaveInteract.js b/src/interaction/slaveInteract.js
index 39e89da9c451c55066e940cd94fc4000f1c3d1d7..16124cac5f017cc11a83fa894b4c325890245cde 100644
--- a/src/interaction/slaveInteract.js
+++ b/src/interaction/slaveInteract.js
@@ -3409,7 +3409,7 @@ App.UI.SlaveInteract.generateRows = function(array, slave, category, accessCheck
 				break;
 			}
 		}
-		// Some items will never be in App.data.misc, especially "none" if it falls in between harsh and nice data sets. Trying to look it up would cause an error, which is what access check works around.
+		// Some items will never be in App.Data.slaveWear, especially "none" if it falls in between harsh and nice data sets. Trying to look it up would cause an error, which is what access check works around.
 		let unlocked = false;
 		if (accessCheck === true) {
 			if (category === "chastity") {
diff --git a/src/js/rulesAssistantOptions.js b/src/js/rulesAssistantOptions.js
index 99e1a87ce69dd66435e219ec4773de7b4c3c9ca9..3310b5a16a4043cb17badfcacdbd0ee23ef71a12 100644
--- a/src/js/rulesAssistantOptions.js
+++ b/src/js/rulesAssistantOptions.js
@@ -1792,11 +1792,11 @@ globalThis.rulesAssistantOptions = (function() {
 			];
 			super("Clothes", items);
 
-			const nclothes = isItemAccessible.array(App.Data.misc.niceClothes);
+			const nclothes = isItemAccessible.array(App.Data.slaveWear.niceClothes);
 			nclothes.sort(function(a, b) { if (a[0] < b[0]) { return -1; } if (a[0] > b[0]) { return 1; } return 0; });
 			this._nice = new ListSubSection(this, "Nice", nclothes);
 
-			const hclothes = isItemAccessible.array(App.Data.misc.harshClothes);
+			const hclothes = isItemAccessible.array(App.Data.slaveWear.harshClothes);
 			hclothes.sort(function(a, b) { if (a[0] < b[0]) { return -1; } if (a[0] > b[0]) { return 1; } return 0; });
 
 			this._harsh = new ListSubSection(this, "Harsh", hclothes);
@@ -1819,11 +1819,11 @@ globalThis.rulesAssistantOptions = (function() {
 			];
 			super("Collar", items);
 
-			const niceCollars = isItemAccessible.array(App.Data.misc.niceCollars);
+			const niceCollars = isItemAccessible.array(App.Data.slaveWear.niceCollars);
 			niceCollars.sort(function(a, b) { if (a[0] < b[0]) { return -1; } if (a[0] > b[0]) { return 1; } return 0; });
 			this._nice = new ListSubSection(this, "Nice", niceCollars);
 
-			const harshCollars = isItemAccessible.array(App.Data.misc.harshCollars);
+			const harshCollars = isItemAccessible.array(App.Data.slaveWear.harshCollars);
 			harshCollars.sort(function(a, b) { if (a[0] < b[0]) { return -1; } if (a[0] > b[0]) { return 1; } return 0; });
 			this._harsh = new ListSubSection(this, "Harsh", harshCollars);
 
@@ -1840,7 +1840,7 @@ globalThis.rulesAssistantOptions = (function() {
 
 	class MaskList extends ListSelector {
 		constructor() {
-			const pairs = [["No mask", "none"]].concat(isItemAccessible.array(App.Data.misc.faceAccessory ));
+			const pairs = [["No mask", "none"]].concat(isItemAccessible.array(App.Data.slaveWear.faceAccessory ));
 			super("Mask", pairs);
 			this.setValue(current_rule.set.faceAccessory );
 			this.onchange = (value) => current_rule.set.faceAccessory  = value;
@@ -1849,7 +1849,7 @@ globalThis.rulesAssistantOptions = (function() {
 
 	class GagList extends ListSelector {
 		constructor() {
-			const pairs = [["No gag", "none"]].concat(isItemAccessible.array(App.Data.misc.mouthAccessory ));
+			const pairs = [["No gag", "none"]].concat(isItemAccessible.array(App.Data.slaveWear.mouthAccessory ));
 			super("Gag", pairs);
 			this.setValue(current_rule.set.mouthAccessory );
 			this.onchange = (value) => current_rule.set.mouthAccessory = value;
@@ -1857,7 +1857,7 @@ globalThis.rulesAssistantOptions = (function() {
 	}
 	class ShoeList extends ListSelector {
 		constructor() {
-			super("Shoes", isItemAccessible.array(App.Data.misc.shoes));
+			super("Shoes", isItemAccessible.array(App.Data.slaveWear.shoes));
 			this.setValue(current_rule.set.shoes);
 			this.onchange = (value) => current_rule.set.shoes = value;
 		}
@@ -1865,7 +1865,7 @@ globalThis.rulesAssistantOptions = (function() {
 
 	class CorsetList extends ListSelector {
 		constructor() {
-			super("Corsetage", isItemAccessible.array(App.Data.misc.bellyAccessories));
+			super("Corsetage", isItemAccessible.array(App.Data.slaveWear.bellyAccessories));
 			this.setValue(current_rule.set.bellyAccessory);
 			this.onchange = (value) => current_rule.set.bellyAccessory = value;
 		}
@@ -1911,7 +1911,7 @@ globalThis.rulesAssistantOptions = (function() {
 
 	class VagAccVirginsList extends ListSelector {
 		constructor() {
-			super("Vaginal accessories for virgins", isItemAccessible.array(App.Data.misc.vaginalAccessories));
+			super("Vaginal accessories for virgins", isItemAccessible.array(App.Data.slaveWear.vaginalAccessories));
 			this.setValue(current_rule.set.virginAccessory);
 			this.onchange = (value) => current_rule.set.virginAccessory = value;
 		}
@@ -1919,7 +1919,7 @@ globalThis.rulesAssistantOptions = (function() {
 
 	class VagAccAVirginsList extends ListSelector {
 		constructor() {
-			super("Vaginal accessories for anal virgins", isItemAccessible.array(App.Data.misc.vaginalAccessories));
+			super("Vaginal accessories for anal virgins", isItemAccessible.array(App.Data.slaveWear.vaginalAccessories));
 			this.setValue(current_rule.set.aVirginAccessory);
 			this.onchange = (value) => current_rule.set.aVirginAccessory = value;
 		}
@@ -1927,7 +1927,7 @@ globalThis.rulesAssistantOptions = (function() {
 
 	class VagAccOtherList extends ListSelector {
 		constructor() {
-			super("Vaginal accessories for other slaves", isItemAccessible.array(App.Data.misc.vaginalAccessories));
+			super("Vaginal accessories for other slaves", isItemAccessible.array(App.Data.slaveWear.vaginalAccessories));
 			this.setValue(current_rule.set.vaginalAccessory);
 			this.onchange = (value) => current_rule.set.vaginalAccessory = value;
 		}
@@ -1935,7 +1935,7 @@ globalThis.rulesAssistantOptions = (function() {
 
 	class VaginalAttachmentsList extends ListSelector {
 		constructor() {
-			super("Vaginal attachments for slaves with vaginal accessories", isItemAccessible.array(App.Data.misc.vaginalAttachments));
+			super("Vaginal attachments for slaves with vaginal accessories", isItemAccessible.array(App.Data.slaveWear.vaginalAttachments));
 			this.setValue(current_rule.set.vaginalAttachment);
 			this.onchange = (value) => current_rule.set.vaginalAttachment = value;
 		}
@@ -1955,7 +1955,7 @@ globalThis.rulesAssistantOptions = (function() {
 
 	class DickAccVirginsList extends ListSelector {
 		constructor() {
-			super("Dick accessories for anal virgins", isItemAccessible.array(App.Data.misc.dickAccessories));
+			super("Dick accessories for anal virgins", isItemAccessible.array(App.Data.slaveWear.dickAccessories));
 			this.setValue(current_rule.set.aVirginDickAccessory);
 			this.onchange = (value) => current_rule.set.aVirginDickAccessory = value;
 		}
@@ -1963,7 +1963,7 @@ globalThis.rulesAssistantOptions = (function() {
 
 	class DickAccOtherList extends ListSelector {
 		constructor() {
-			super("Dick accessories for other slaves", isItemAccessible.array(App.Data.misc.dickAccessories));
+			super("Dick accessories for other slaves", isItemAccessible.array(App.Data.slaveWear.dickAccessories));
 			this.setValue(current_rule.set.dickAccessory);
 			this.onchange = (value) => current_rule.set.dickAccessory = value;
 		}
@@ -1983,7 +1983,7 @@ globalThis.rulesAssistantOptions = (function() {
 
 	class ButtplugsVirginsList extends ListSelector {
 		constructor() {
-			super("Buttplugs for anal virgins", isItemAccessible.array(App.Data.misc.buttplugs));
+			super("Buttplugs for anal virgins", isItemAccessible.array(App.Data.slaveWear.buttplugs));
 			this.setValue(current_rule.set.aVirginButtplug);
 			this.onchange = (value) => current_rule.set.aVirginButtplug = value;
 		}
@@ -1991,7 +1991,7 @@ globalThis.rulesAssistantOptions = (function() {
 
 	class ButtplugsOtherList extends ListSelector {
 		constructor() {
-			super("Buttplugs for other slaves", isItemAccessible.array(App.Data.misc.buttplugs));
+			super("Buttplugs for other slaves", isItemAccessible.array(App.Data.slaveWear.buttplugs));
 			this.setValue(current_rule.set.buttplug);
 			this.onchange = (value) => current_rule.set.buttplug = value;
 		}
@@ -1999,7 +1999,7 @@ globalThis.rulesAssistantOptions = (function() {
 
 	class ButtplugAttachmentsList extends ListSelector {
 		constructor() {
-			super("Buttplug attachments for slaves with buttplugs", isItemAccessible.array(App.Data.misc.buttplugAttachments));
+			super("Buttplug attachments for slaves with buttplugs", isItemAccessible.array(App.Data.slaveWear.buttplugAttachments));
 			this.setValue(current_rule.set.buttplugAttachment);
 			this.onchange = (value) => current_rule.set.buttplugAttachment = value;
 		}
diff --git a/src/interaction/wardrobeUse.js b/src/interaction/wardrobeUse.js
index 8df74b06d91982fd3ee6f5c94af8a0d037b40302..772d8800f22d362d24390ad902940a9c8e6c0f86 100644
--- a/src/interaction/wardrobeUse.js
+++ b/src/interaction/wardrobeUse.js
@@ -33,7 +33,7 @@ App.UI.Wardrobe.clothes = function(slave) {
 
 		let clothingOption;
 		// Nice clothes
-		App.Data.misc.niceClothes.forEach(item => {
+		App.Data.slaveWear.niceClothes.forEach(item => {
 			clothingOption = {
 				text: item.name,
 				updateSlave: {clothes: item.value, choosesOwnClothes: 0},
@@ -42,7 +42,7 @@ App.UI.Wardrobe.clothes = function(slave) {
 			niceOptionsArray.push(clothingOption);
 		});
 		// Harsh clothes
-		App.Data.misc.harshClothes.forEach(item => {
+		App.Data.slaveWear.harshClothes.forEach(item => {
 			clothingOption = {
 				text: item.name,
 				updateSlave: {clothes: item.value, choosesOwnClothes: 0},
@@ -114,7 +114,7 @@ App.UI.Wardrobe.collar = function(slave) {
 
 	let clothingOption;
 	// Nice collar
-	App.Data.misc.niceCollars.forEach(item => {
+	App.Data.slaveWear.niceCollars.forEach(item => {
 		clothingOption = {
 			text: item.name,
 			updateSlave: {collar: item.value},
@@ -123,7 +123,7 @@ App.UI.Wardrobe.collar = function(slave) {
 		niceOptionsArray.push(clothingOption);
 	});
 	// Harsh collar
-	App.Data.misc.harshCollars.forEach(item => {
+	App.Data.slaveWear.harshCollars.forEach(item => {
 		clothingOption = {
 			text: item.name,
 			updateSlave: {collar: item.value},
@@ -179,7 +179,7 @@ App.UI.Wardrobe.mask = function(slave) {
 	let array = [];
 
 	let clothingOption;
-	App.Data.misc.faceAccessory.forEach(item => {
+	App.Data.slaveWear.faceAccessory.forEach(item => {
 		clothingOption = {
 			text: item.name,
 			updateSlave: {faceAccessory: item.value},
@@ -239,7 +239,7 @@ App.UI.Wardrobe.mouth = function(slave) {
 
 	let clothingOption;
 	// mouthAccessory
-	App.Data.misc.mouthAccessory.forEach(item => {
+	App.Data.slaveWear.mouthAccessory.forEach(item => {
 		clothingOption = {
 			text: item.name,
 			updateSlave: {mouthAccessory: item.value},
@@ -318,7 +318,7 @@ App.UI.Wardrobe.shoes = function(slave) {
 	choice.textContent = (`${slave.shoes} `);
 	label.appendChild(choice);
 
 	/* We have "barefoot" in App.Data.Misc to cover for this
 	// Choose her own
 	if (slave.shoes !== `none`) {
 		let choiceOptionsArray = [];
@@ -331,7 +331,7 @@ App.UI.Wardrobe.shoes = function(slave) {
 	let optionsArray = [];
 
 	let clothingOption;
-	App.Data.misc.shoes.forEach(item => {
+	App.Data.slaveWear.shoes.forEach(item => {
 		clothingOption = {
 			text: item.name,
 			updateSlave: {shoes: item.value},
@@ -420,7 +420,7 @@ App.UI.Wardrobe.bellyAccessory = function(slave) {
 	let optionsArray = [];
 
 	let clothingOption;
-	App.Data.misc.bellyAccessories.forEach(item => {
+	App.Data.slaveWear.bellyAccessories.forEach(item => {
 		clothingOption = {
 			text: item.name,
 			updateSlave: {bellyAccessory: item.value},
@@ -497,7 +497,7 @@ App.UI.Wardrobe.buttplug = function(slave) {
 	let optionsArray = [];
 
 	let clothingOption;
-	App.Data.misc.buttplugs.forEach(item => {
+	App.Data.slaveWear.buttplugs.forEach(item => {
 		clothingOption = {
 			text: item.name,
 			updateSlave: {buttplug: item.value},
@@ -553,7 +553,7 @@ App.UI.Wardrobe.buttplugAttachment = function(slave) {
 	let optionsArray = [];
 
 	let clothingOption;
-	App.Data.misc.buttplugAttachments.forEach(item => {
+	App.Data.slaveWear.buttplugAttachments.forEach(item => {
 		clothingOption = {
 			text: item.name,
 			updateSlave: {buttplugAttachment: item.value},
@@ -608,7 +608,7 @@ App.UI.Wardrobe.vaginalAccessory = function(slave) {
 	let optionsArray = [];
 
 	let clothingOption;
-	App.Data.misc.vaginalAccessories.forEach(item => {
+	App.Data.slaveWear.vaginalAccessories.forEach(item => {
 		clothingOption = {
 			text: item.name,
 			updateSlave: {vaginalAccessory: item.value},
@@ -665,7 +665,7 @@ App.UI.Wardrobe.vaginalAttachment = function(slave) {
 	let optionsArray = [];
 
 	let clothingOption;
-	App.Data.misc.vaginalAttachments.forEach(item => {
+	App.Data.slaveWear.vaginalAttachments.forEach(item => {
 		clothingOption = {
 			text: item.name,
 			updateSlave: {vaginalAttachment: item.value},
@@ -720,7 +720,7 @@ App.UI.Wardrobe.dickAccessory = function(slave) {
 	let optionsArray = [];
 
 	let clothingOption;
-	App.Data.misc.dickAccessories.forEach(item => {
+	App.Data.slaveWear.dickAccessories.forEach(item => {
 		clothingOption = {
 			text: item.name,
 			updateSlave: {dickAccessory: item.value},
@@ -802,7 +802,7 @@ App.UI.Wardrobe.chastity = function(slave) {
 	let optionsArray = [];
 
 	let clothingOption;
-	App.Data.misc.chastityDevices.forEach(item => {
+	App.Data.slaveWear.chastityDevices.forEach(item => {
 		clothingOption = {
 			text: item.name,
 			updateSlave: {},
@@ -318,7 +318,7 @@ App.UI.Wardrobe.shoes = function(slave) {
 	label.appendChild(choice);
 
-	/* We have "barefoot" in App.Data.Misc to cover for this
+	/* We have "barefoot" in App.Data.slaveWear to cover for this
 	// Choose her own
 	if (slave.shoes !== `none`) {
diff --git a/src/js/itemAvailability.js b/src/js/itemAvailability.js
index f167beaa2eb9baae43e2b359478cacf184c70095..f0c5fc0cb1f13e86ed1266dd6d4e060240306d8a 100644
--- a/src/js/itemAvailability.js
+++ b/src/js/itemAvailability.js
@@ -20,40 +20,40 @@ globalThis.isItemAccessible = (function() {
 		switch (category) {
 			case "clothing":
 			case "clothes":
-				niceDB = App.Data.misc.niceClothes;
-				harshDB = App.Data.misc.harshClothes;
+				niceDB = App.Data.slaveWear.niceClothes;
+				harshDB = App.Data.slaveWear.harshClothes;
 				break;
 			case "collar":
-				niceDB = App.Data.misc.niceCollars;
-				harshDB = App.Data.misc.harshCollars;
+				niceDB = App.Data.slaveWear.niceCollars;
+				harshDB = App.Data.slaveWear.harshCollars;
 				break;
 			case "bellyAccessory":
-				niceDB = App.Data.misc.bellyAccessories;
+				niceDB = App.Data.slaveWear.bellyAccessories;
 				break;
 			case "buttplug":
-				niceDB = App.Data.misc.buttplugs;
+				niceDB = App.Data.slaveWear.buttplugs;
 				break;
 			case "buttplugAttachment":
-				niceDB = App.Data.misc.buttplugAttachments;
+				niceDB = App.Data.slaveWear.buttplugAttachments;
 				break;
 			case "vaginalAccessory":
-				niceDB = App.Data.misc.vaginalAccessories;
+				niceDB = App.Data.slaveWear.vaginalAccessories;
 				break;
 			case "vaginalAttachment":
-				niceDB = App.Data.misc.vaginalAttachments;
+				niceDB = App.Data.slaveWear.vaginalAttachments;
 				break;
 			case "dickAccessory":
-				niceDB = App.Data.misc.vaginalAccessories;
+				niceDB = App.Data.slaveWear.vaginalAccessories;
 				break;
 			case "shoes":
-				niceDB = App.Data.misc.shoes;
+				niceDB = App.Data.slaveWear.shoes;
 				break;
 			case "chastity":
-				niceDB = App.Data.misc.chastityDevices;
+				niceDB = App.Data.slaveWear.chastityDevices;
 				break;
 			default:
 				console.log(`made a category for ${category} automatically, may need to define this by hand`);
-				niceDB = App.Data.misc[category];
+				niceDB = App.Data.slaveWear[category];
 				break;
 		}
 		let item = niceDB.find((i) => i.value === string);
@@ -61,14 +61,14 @@ globalThis.isItemAccessible = (function() {
 			item = harshDB.find((i) => i.value === string);
 		}
 		if (!item) {
-			console.log(`${string} is not a registered piece of clothing! Check App.Data.misc.${category}`);
+			console.log(`${string} is not a registered piece of clothing! Check App.Data.slaveWear.${category}`);
 			return false; /* couldn't be found */
 		}
 		return isAvailable(item, category, slave);
 	}
 	/**
 	 * Returns array of wearable clothing in format [name, value], basically player facing / game data.
 	 * @param {Array} db Array to look in (such as App.Data.misc.niceClothes)
 	 * @returns {Array}
 	 */
 	function array(db) {
@@ -61,14 +61,14 @@ globalThis.isItemAccessible = (function() {
 	/**
 	 * Returns array of wearable clothing in format [name, value], basically player facing / game data.
-	 * @param {Array} db Array to look in (such as App.Data.misc.niceClothes)
+	 * @param {Array} db Array to look in (such as App.Data.slaveWear.niceClothes)
 	 * @returns {Array}
 	 */